@@ -34,7 +34,7 @@ class CValidate extends CObject
 
 	function email( $data, $errmsg = "" )
 	{
-		return $this->_check( preg_match( '/\\A(?:~([a-z0-9][a-z0-9_\\-\\.\\+]*)@([a-z0-9][a-z0-9\\.\\-]{0,63}\\.(com|org|net|biz|info|name|net|pro|aero|coop|museum|[a-z]{2,4}))$)\\z/i', $errmsg ) );
+		return $this->_check( preg_match( '/\\A(?:~([a-z0-9][a-z0-9_\\-\\.\\+]*)@([a-z0-9][a-z0-9\\.\\-]{0,63}\\.(com|org|net|biz|info|name|net|pro|aero|coop|museum|[a-z]{2,4}))$)\\z/i', $data ), $errmsg );
 	}
 
 	
